angular.module('quipsphere.directives', [])

  .constant('msdElasticConfig', {
    append: ''
  })

  .directive('msdElastic', [
    '$timeout', '$window', 'msdElasticConfig',
    function($timeout, $window, config) {
      'use strict';

      return {
        require: 'ngModel',
        restrict: 'A, C',
        link: function(scope, element, attrs, ngModel) {

          // cache a reference to the DOM element
          var ta = element[0],
              $ta = element;

          // ensure the element is a textarea, and browser is capable
          if (ta.nodeName !== 'TEXTAREA' || !$window.getComputedStyle) {
            return;
          }

          // set these properties before measuring dimensions
          $ta.css({
            'overflow': 'hidden',
            'overflow-y': 'hidden',
            'word-wrap': 'break-word'
          });

          // force text reflow
          var text = ta.value;
          ta.value = '';
          ta.value = text;

          var append = attrs.msdElastic ? attrs.msdElastic.replace(/\\n/g, '\n') : config.append,
              $win = angular.element($window),
              mirrorInitStyle = 'position: absolute; top: -999px; right: auto; bottom: auto;' +
                                'left: 0; overflow: hidden; -webkit-box-sizing: content-box;' +
                                '-moz-box-sizing: content-box; box-sizing: content-box;' +
                                'min-height: 0 !important; height: 0 !important; padding: 0;' +
                                'word-wrap: break-word; border: 0;',
              $mirror = angular.element('<textarea aria-hidden="true" tabindex="-1" ' +
                                        'style="' + mirrorInitStyle + '"/>').data('elastic', true),
              mirror = $mirror[0],
              taStyle = getComputedStyle(ta),
              resize = taStyle.getPropertyValue('resize'),
              borderBox = taStyle.getPropertyValue('box-sizing') === 'border-box' ||
                          taStyle.getPropertyValue('-moz-box-sizing') === 'border-box' ||
                          taStyle.getPropertyValue('-webkit-box-sizing') === 'border-box',
              boxOuter = !borderBox ? {width: 0, height: 0} : {
                            width:  parseInt(taStyle.getPropertyValue('border-right-width'), 10) +
                                    parseInt(taStyle.getPropertyValue('padding-right'), 10) +
                                    parseInt(taStyle.getPropertyValue('padding-left'), 10) +
                                    parseInt(taStyle.getPropertyValue('border-left-width'), 10),
                            height: parseInt(taStyle.getPropertyValue('border-top-width'), 10) +
                                    parseInt(taStyle.getPropertyValue('padding-top'), 10) +
                                    parseInt(taStyle.getPropertyValue('padding-bottom'), 10) +
                                    parseInt(taStyle.getPropertyValue('border-bottom-width'), 10)
                          },
              minHeightValue = parseInt(taStyle.getPropertyValue('min-height'), 10),
              heightValue = parseInt(taStyle.getPropertyValue('height'), 10),
              minHeight = Math.max(minHeightValue, heightValue) - boxOuter.height,
              maxHeight = parseInt(taStyle.getPropertyValue('max-height'), 10),
              mirrored,
              active,
              copyStyle = ['font-family',
                           'font-size',
                           'font-weight',
                           'font-style',
                           'letter-spacing',
                           'line-height',
                           'text-transform',
                           'word-spacing',
                           'text-indent'];

          // exit if elastic already applied (or is the mirror element)
          if ($ta.data('elastic')) {
            return;
          }

          // Opera returns max-height of -1 if not set
          maxHeight = maxHeight && maxHeight > 0 ? maxHeight : 9e4;

          // append mirror to the DOM
          if (mirror.parentNode !== document.body) {
            angular.element(document.body).append(mirror);
          }

          // set resize and apply elastic
          $ta.css({
            'resize': (resize === 'none' || resize === 'vertical') ? 'none' : 'horizontal'
          }).data('elastic', true);

          /*
           * methods
           */

          function initMirror() {
            var mirrorStyle = mirrorInitStyle;

            mirrored = ta;
            // copy the essential styles from the textarea to the mirror
            taStyle = getComputedStyle(ta);
            angular.forEach(copyStyle, function(val) {
              mirrorStyle += val + ':' + taStyle.getPropertyValue(val) + ';';
            });
            mirror.setAttribute('style', mirrorStyle);
          }

          function adjust() {
            var taHeight,
                taComputedStyleWidth,
                mirrorHeight,
                width,
                overflow;

            if (mirrored !== ta) {
              initMirror();
            }

            // active flag prevents actions in function from calling adjust again
            if (!active) {
              active = true;

              mirror.value = ta.value + append; // optional whitespace to improve animation
              mirror.style.overflowY = ta.style.overflowY;

              taHeight = ta.style.height === '' ? 'auto' : parseInt(ta.style.height, 10);

              taComputedStyleWidth = getComputedStyle(ta).getPropertyValue('width');

              // ensure getComputedStyle has returned a readable 'used value' pixel width
              if (taComputedStyleWidth.substr(taComputedStyleWidth.length - 2, 2) === 'px') {
                // update mirror width in case the textarea width has changed
                width = parseInt(taComputedStyleWidth, 10) - boxOuter.width;
                mirror.style.width = width + 'px';
              }

              mirrorHeight = mirror.scrollHeight;

              if (mirrorHeight > maxHeight) {
                mirrorHeight = maxHeight;
                overflow = 'scroll';
              } else if (mirrorHeight < minHeight) {
                mirrorHeight = minHeight;
              }
              mirrorHeight += boxOuter.height;
              ta.style.overflowY = overflow || 'hidden';

              if (taHeight !== mirrorHeight) {
                scope.$emit('elastic:resize', $ta, taHeight, mirrorHeight);
                ta.style.height = mirrorHeight + 'px';
              }

              // small delay to prevent an infinite loop
              $timeout(function() {
                active = false;
              }, 1, false);

            }
          }

          function forceAdjust() {
            active = false;
            adjust();
          }

          /*
           * initialise
           */

          // listen
          if ('onpropertychange' in ta && 'oninput' in ta) {
            // IE9
            ta['oninput'] = ta.onkeyup = adjust;
          } else {
            ta['oninput'] = adjust;
          }

          $win.bind('resize', forceAdjust);

          scope.$watch(function() {
            return ngModel.$modelValue;
          }, function(newValue) {
            forceAdjust();
          });

          scope.$on('elastic:adjust', function() {
            initMirror();
            forceAdjust();
          });

          $timeout(adjust, 0, false);

          /*
           * destroy
           */

          scope.$on('$destroy', function() {
            $mirror.remove();
            $win.unbind('resize', forceAdjust);
          });
        }
      };
    }
  ])


.directive('myTabs', function() {
  return {
    restrict: 'E',
    transclude: true,
    scope: {},
    controller: function($scope) {
      var tabs = $scope.tabs = [];

      $scope.select = function(tab) {
        angular.forEach(tabs, function(tab) {
          tab.selected = false;
        });
        tab.selected = true;
        $scope.$emit('my-tabs-changed', tab);
      };

      this.addTab = function(tab) {
        if (tabs.length === 0) {
          $scope.select(tab);
        }
        tabs.push(tab);
      };
    },
    templateUrl: 'views/common/my-tabs.html'
  };
})

.directive('myTab', function() {
  return {
    require: '^myTabs',
    restrict: 'E',
    transclude: true,
    scope: {
      title: '@'
    },
    link: function(scope, element, attrs, tabsCtrl) {
      tabsCtrl.addTab(scope);
    },
    templateUrl: 'views/common/my-tab.html'
  };
})

.directive('loginValidate', function($http) {
  return {
    require: 'ngModel',
    link: function(scope, ele, attrs, c) {
      scope.$watch(attrs.ngModel, function() {
                console.log(attrs);
                c.$setValidity('login-validate', true);
        // $http({
        //  method: 'POST',
        //  url: '/api/check/' + attrs.validPin,
        //  data: {'pin': attrs.validPin}
        // }).success(function(data, status, headers, cfg) {
        //  c.$setValidity('valid-pin', data.isValid);
        // }).error(function(data, status, headers, cfg) {
        //  c.$setValidity('valid-pin', false);
        // });
        /*if(pinValue=="12345")
        {
          c.$setValidity('valid-pin', true);
        }
        else
        {
          c.$setValidity('valid-pin', false);
        }*/
      });
    }
  };
})


.directive('showHideContainer', function(){
  return {
    scope: {
    },
    controller: function($scope, $element, $attrs) {
      $scope.show = false;

      $scope.toggleType = function($event){
        $event.stopPropagation();
        $event.preventDefault();

        $scope.show = !$scope.show;

        // Emit event
        $scope.$broadcast("toggle-type", $scope.show);
      };
    },
    templateUrl: 'views/common/show-hide-password.html',
    restrict: 'A',
    replace: false,
    transclude: true
  };
})


.directive('showHideInput', function(){
  return {
    scope: {
    },
    link: function(scope, element, attrs) {
      // listen to event
      scope.$on("toggle-type", function(event, show){
        var password_input = element[0],
            input_type = password_input.getAttribute('type');

        if(!show)
        {
          password_input.setAttribute('type', 'password');
        }

        if(show)
        {
          password_input.setAttribute('type', 'text');
        }
      });
    },
    require: '^showHideContainer',
    restrict: 'A',
    replace: false,
    transclude: false
  };
})

.directive('zurbSelect', [function(){
  return {
    scope: {
      label: '@', // optional
      changeCallback: '&',
      options: '='
    },
    restrict: 'E',
    replace: true, // optional 
    templateUrl: 'dd.html',
    link: function(scope, element, attr) { }
  };
}])

.directive('browseFile',[function($ionicPopup){
    return {
        scope:{

        },
        replace:true,
        restrict:'AE',
        link:function(scope,elem,attrs){

            scope.browseFile=function(){
                document.getElementById('browseBtn').click();
            }

            angular.element(document.getElementById('browseBtn')).on('change',function(e){

               var file=e.target.files[0];

               angular.element(document.getElementById('browseBtn')).val('');

               var fileReader=new FileReader();

               fileReader.onload=function(event){
                  //angular.element('#clickgo').trigger('click');
                  //document.getElementById('clickgo').click();
       //             $rootScope.$apply(function () {   
       //               $rootScope.goto('app.editquip',"{}");            // 3
            //   //$rootScope.someText = 'This is BAD practice, dude ! :(';
            // });
                  //$rootScope.goto('app.editquip',"{}");
                //state.go('app.editquip');
                // scope.$apply(function(){
                //  scope.gotoeditquip = 1; 
                // });
                // console.log(scope.gotoeditquip);
                  //$rootScope.gotoeditquip = 1;
                  // scope.$apply(
                  //    function(){
                  //        $state.go('app.editquip');
                  //        //scope.goto('app.editquip',{});
                  //    });
                  //$state.go("app.editqui");
                  // console.log(event.loaded);
                   
               };

               fileReader.readAsDataURL(file);
            });

        },
        templateUrl:'browsefile.html'
    }
}])

.directive('autolinker', ['$timeout',
    function($timeout) {
        return {
            restrict: 'A',
            link: function(scope, element, attrs) {
                $timeout(function() {
                    var eleHtml = element.html();

                    if (eleHtml === '') {
                        return false;
                    }

                    var text = Autolinker.link(eleHtml, {
                        className: 'autolinker',
                        newWindow: false
                    });

                    element.html(text);

                    var autolinks = element[0].getElementsByClassName('autolinker');

                    for (var i = 0; i < autolinks.length; i++) {
                        angular.element(autolinks[i]).bind('click', function(e) {
                            var href = e.target.href;
                            console.log('autolinkClick, href: ' + href);

                            if (href) {
                                //window.open(href, '_system');
                                window.open(href, '_blank');
                            }

                            e.preventDefault();
                            return false;
                        });
                    }
                }, 0);
            }
        }
    }
])

//rate
.directive('proStar', function () {
    return {
        restrict: 'A',
        template: '<div class="prostar-ratings">' +
            '<div class="prostar-empty-stars"></div>' +
            '<div class="prostar-full-stars" style="width:{{startPercent}}"></div>' +
            '</div>',
        scope: {
            ratingValue: '=',
            max: '=',
            onRatingSelected: '&'
        },
        link: function (scope, elem, attrs) {

            var updateStars = function () {
              scope.startPercent = ((scope.ratingValue/5)*100)+'%';
              console.log(scope.startPercent);
            };

            scope.toggle = function (index) {
                scope.ratingValue = index + 1;
                scope.onRatingSelected({
                    rating: index + 1
                });
            };

            scope.$watch('ratingValue', function (oldVal, newVal) {
                updateStars();
            });
        }
    }
})
.directive('starRating', function () {
    return {
        restrict: 'A',
        template: '<ul class="rating">' +
            '<li ng-repeat="star in stars" ng-class="star" ng-click="toggle($index)">' +
            '<i class="ion-android-star star.filled"></i>' +
            '</li>' +
            '</ul>',
        scope: {
            ratingValue: '=',
            max: '=',
            onRatingSelected: '&'
        },
        link: function (scope, elem, attrs) {

            var updateStars = function () {
                scope.stars = [];
                for (var i = 0; i < scope.max; i++) {
                    scope.stars.push({
                        filled: i < scope.ratingValue
                    });
                }
            };

            scope.toggle = function (index) {
                scope.ratingValue = index + 1;
                scope.onRatingSelected({
                    rating: index + 1
                });
            };

            scope.$watch('ratingValue', function (oldVal, newVal) {
                if (newVal) {
                    updateStars();
                }
            });
        }
    }
})

 .directive('starRatingProfile',
    function() {
        return {
            restrict : 'A',
            template : '<ul class="rating_profile">'
                     + '    <li ng-repeat="star in stars" ng-class="star">'
                     + '<i class="{{star.st}} star.filled"></i>'
                     + '</li>'
                     + '</ul>',
            scope : {
                ratingValue : '=',
                max : '=',
                onRatingSelected : '&'
            },
            link : function(scope, elem, attrs) {
                var updateStars = function() {
                    scope.stars = [];
                    if(scope.ratingValue % 1 != 0){
                          var a = 0;
                          a = parseInt(scope.ratingValue);
  
                       for ( var i = 0; i < scope.max; i++) {
                            
                            if(a == i){
                              scope.stars.push({
                                  filled: true,
                                  st:'ion-android-star-half'
                              });
                            }else{
                              scope.stars.push({
                                  filled: i < a,
                                  st:'ion-android-star'
                             });
                           }
                         }
                             
                      }else{
                          for ( var i = 0; i < scope.max; i++) {
                            scope.stars.push({
                                  st:'ion-android-star',
                                  filled : i < scope.ratingValue
                             });
                          }
                       }
                };

                scope.$watch('ratingValue',
                    function(oldVal, newVal) {
                        if (newVal) {
                            updateStars();
                        }
                    }
                );
            }
        };
    })

 .directive('starStarList',
    function() {
        return {
            restrict : 'A',
            template : '<ul class="star-rating">'
                     + '    <li ng-repeat="star in stars" ng-class="star">'
                     + '<i class="ion-android-star star.filled"></i>'
                     + '</li>'
                     + '</ul>',
            scope : {
                ratingValue : '=',
                max : '=',
                onRatingSelected : '&'
            },
            link : function(scope, elem, attrs) {
                var updateStars = function() {
                    scope.stars = [];
                    for ( var i = 0; i < scope.max; i++) {
                        scope.stars.push({
                            filled : i < scope.ratingValue
                        });
                    }
                };

                scope.$watch('ratingValue',
                    function(oldVal, newVal) {
                        if (newVal) {
                            updateStars();
                        }
                    }
                );
            }
        };
    })

 .directive('starRatingSphere',
    function() {
        return {
            restrict : 'A',
            template : '<ul class="rating_sphere">'
                     + '    <li ng-repeat="star in stars" ng-class="star">'
                     + '<i class="ion-android-star star.filled"></i>'
                     + '</li>'
                     + '</ul>',
            scope : {
                ratingValue : '=',
                max : '=',
                onRatingSelected : '&'
            },
            link : function(scope, elem, attrs) {
                var updateStars = function() {
                    scope.stars = [];
                    for ( var i = 0; i < scope.max; i++) {
                        scope.stars.push({
                            filled : i < scope.ratingValue
                        });
                    }
                };

                scope.$watch('ratingValue',
                    function(oldVal, newVal) {
                        if (newVal) {
                            updateStars();
                        }
                    }
                );
            }
        };
    })

.directive('draggable', function() {
    return function(scope, element) {
        // this gives us the native JS object
        var el = element[0];

        el.draggable = true;

        el.addEventListener(
            'dragstart',
            function(e) {
                console.log('x');
                e.dataTransfer.effectAllowed = 'move';
                e.dataTransfer.setData('Text', this.id);
                this.classList.add('drag');
                return false;
            },
            false
        );

        el.addEventListener(
            'dragend',
            function(e) {
                this.classList.remove('drag');
                return false;
            },
            false
        );
    }
})


.directive('tabheader',[function(){
    return {
    template: '<div class="title">'+
                '<div class="home-button-left {{currenturl === \'app.home\' ? \'q_blue\':\'\'}}" ng-click="goto(\'app.home\',{}, \'\', \'right\')" >'+
                    '<img class="headicon" src="img/home.png" >'+
                '</div>'+
                '<div class="home-button-right {{currenturl === \'app.mysphere\' ? \'q_blue\':\'\'}}" ng-click="goto(\'app.mysphere\',{}, \'\', \'left\')" >'+
                  '<img class="headicon"  src="img/sphere-icon.png">'+
                '</div>'+
              '</div>'
    };
}])

.directive('tabfooter',[function(){
    return {
     template: '<div class="footer-container">'+
        '<div class="footer-buttons" style="padding:0;height: 100%;">'+
            '<div class="row" style="padding:0; height:100%">'+
                '<div id="divNavHome" on-tap="reRoute(\'go\',\'home\');goto(\'app.home\',{});" class="col navbtn {{currenturl === \'app.home\'? \'activefooter\': \'\' }}" >'+
                    '<img id=\'navHome\'  class="footer-icon {{currenturl === \'app.home\'? \'\': \'\' }}" src="img/bonfire1.png"/>'+
                '</div>'+
                '<div id="divNavNewsf" on-tap="reRoute(\'go\',\'newsfeed\');goto(\'app.newsfeed\',{});"  class="col navbtn {{currenturl === \'app.newsfeed\'? \'activefooter\': \'\' }}"  >'+
                    '<img id=\'navNewsf\' class="footer-icon {{currenturl === \'app.newsfeed\'? \'\': \'\' }} "  src="img/home1.png" />'+
                '</div>'+
                '<div class="col">'+
                    '<img id="mic-icon" ng-show="canQuip"  on-tap="reRoute(\'go\',\'recorder\');openRecorderModal(\'1\');" ng-src="img/quipers_blue.png"/>'+
                    '<img id="mic-icon" ng-show="!canQuip"  on-tap="CannotQuip();" ng-src="img/quipers_blue.png"/>'+
                '</div>'+
                '<div id="divNavChat" on-tap="goto(\'app.chathome\',{});" class="col navbtn {{currenturl === \'app.chathome\'? \'activefooter\': \'\' }}">'+
                        '<img class="footer-icon {{currenturl === \'app.chathome\'? \'\': \'\' }}" ng-src="img/msg1.png"  />'+
                        '<span class="badge badge-assertive badgefixfoot {{(showchatbadge) ? \'elshow\' : \'elhide\' }}" >{{countNewChatMsgs}}</span>'+
                '</div>'+
                '<div id="divNavSpheres" on-tap="reRoute(\'go\',\'app.mysphere\');goto(\'app.mysphere\',{});" class="col navbtn {{currenturl === \'app.mysphere\'? \'activefooter\': \'\' }}">'+
                    '<img class="footer-icon {{currenturl === \'app.mysphere\'? \'\': \'\' }}" ng-src="img/sphere1.png" />'+
                    '<img class="mysphere-badge myfooter" ng-src="img/red-white-check.png" >'+
                '</div>'+
            '</div>'+
        '</div>'+
    '</div>'
    };
}])

.directive('tabfootermodal',[function(){
    return {
    template:'<div class="footer-container btmmodal">'+
        '<div class="footer-buttons" style="padding:0;height: 100%;">'+
            '<div class="row" style="padding:0; height:100%">'+
                '<div ng-click="reRoute(\'go\',\'home\');goto(\'app.home\',{});destroyall();" class="col">'+
                    '<img class="footer-icon" src="img/bonfire1.png"/>'+
                '</div>'+
                '<div ng-click="reRoute(\'go\',\'newsfeed\');goto(\'app.newsfeed\',{});destroyall();"  class="col">'+
                    '<img class="footer-icon"  src="img/home1.png" />'+
                '</div>'+
                '<div class="col">'+
                    '<img id="mic-icon" ng-click="reRoute(\'go\',\'recorder\',1);openRecorderModal(\'1\')" ng-src="img/quipers_blue.png"/>'+
                '</div>'+
                '<div ng-click="reRoute(\'go\',\'applist\');goto(\'app.list\',{});destroyall();" class="col">'+
                    '<img class="footer-icon" ng-src="img/msg1.png" />'+
                '</div>'+
                '<div id="divNavSpheres2" ng-click="goto(\'app.mysphere\',{});destroyall();" class="col">'+
                    '<img class="footer-icon" ng-src="img/sphere1.png" />'+
                    '<img class="mysphere-badge myfooter2" ng-src="img/red-white-check.png" >'+
                '</div>'+
            '</div>'+
        '</div>'+
    '</div>'
    };
}])

.directive('timezonelist', function() {
    return {
        restrict : 'A',
        template : '<select>'
                +"<option ng-repeat='timezone in timezones' value='{{timezone.title}}'>{{timezone.content}}</option>"
                +"</select>",
        scope : {
            timezonesArray : '=',
            onRatingSelected : '&'
        },
        link : function(scope, elem, attrs) {
            var updateList = function() {
                console.log(scope);
                scope.timezones = scope.timezonesArray;
            };

            scope.$watch('timezonesArray',
                function(oldVal, newVal) {
                    updateList();
                }
            );
        }
    };
})


.directive('countrylist',[function(){
  return{
    template: "<select id='country-list' ng-model='user_data.country' ng-change='changeCountry(user_data.country)' style='opacity:0; position:absolute;top: 0; right: 0; bottom: 0;left: 0; width: 100%;'>"
                +"<option value=''>Global</option>"
                +"<option value='AF'>Afghanistan</option>"
                +"<option value='AL'>Albania</option>"
                +"<option value='DZ'>Algeria</option>"
                +"<option value='AS'>American Samoa</option>"
                +"<option value='AD'>Andorra</option>"
                +"<option value='AO'>Angola</option>"
                +"<option value='AI'>Anguilla</option>"
                +"<option value='AQ'>Antarctica</option>"
                +"<option value='AG'>Antigua and Barbuda</option>"
                +"<option value='AR'>Argentina</option>"
                +"<option value='AM'>Armenia</option>"
                +"<option value='AW'>Aruba</option>"
                +"<option value='AU'>Australia</option>"
                +"<option value='AT'>Austria</option>"
                +"<option value='AZ'>Azerbaijan</option>"
                +"<option value='BS'>Bahamas</option>"
                +"<option value='BH'>Bahrain</option>"
                +"<option value='BD'>Bangladesh</option>"
                +"<option value='BB'>Barbados</option>"
                +"<option value='BY'>Belarus</option>"
                +"<option value='BE'>Belgium</option>"
                +"<option value='BZ'>Belize</option>"
                +"<option value='BJ'>Benin</option>"
                +"<option value='BM'>Bermuda</option>"
                +"<option value='BT'>Bhutan</option>"
                +"<option value='BO'>Bolivia</option>"
                +"<option value='BA'>Bosnia and Herzegovina</option>"
                +"<option value='BW'>Botswana</option>"
                +"<option value='BR'>Brazil</option>"
                +"<option value='IO'>British Indian Ocean Territory</option>"
                +"<option value='VG'>British Virgin Islands</option>"
                +"<option value='BN'>Brunei</option>"
                +"<option value='BG'>Bulgaria</option>"
                +"<option value='BF'>Burkina Faso</option>"
                +"<option value='BI'>Burundi</option>"
                +"<option value='KH'>Cambodia</option>"
                +"<option value='CM'>Cameroon</option>"
                +"<option value='CA'>Canada</option>"
                +"<option value='CV'>Cape Verde</option>"
                +"<option value='KY'>Cayman Islands</option>"
                +"<option value='CF'>Central African Republic</option>"
                +"<option value='TD'>Chad</option>"
                +"<option value='CL'>Chile</option>"
                +"<option value='CN'>China</option>"
                +"<option value='CX'>Christmas Island</option>"
                +"<option value='CC'>Cocos Islands</option>"
                +"<option value='CO'>Colombia</option>"
                +"<option value='KM'>Comoros</option>"
                +"<option value='CK'>Cook Islands</option>"
                +"<option value='CR'>Costa Rica</option>"
                +"<option value='HR'>Croatia</option>"
                +"<option value='CU'>Cuba</option>"
                +"<option value='CW'>Curacao</option>"
                +"<option value='CY'>Cyprus</option>"
                +"<option value='CZ'>Czech Republic</option>"
                +"<option value='CD'>Democratic Republic of the Congo</option>"
                +"<option value='DK'>Denmark</option>"
                +"<option value='DJ'>Djibouti</option>"
                +"<option value='DM'>Dominica</option>"
                +"<option value='DO'>Dominican Republic</option>"
                +"<option value='TL'>East Timor</option>"
                +"<option value='EC'>Ecuador</option>"
                +"<option value='EG'>Egypt</option>"
                +"<option value='SV'>El Salvador</option>"
                +"<option value='GQ'>Equatorial Guinea</option>"
                +"<option value='ER'>Eritrea</option>"
                +"<option value='EE'>Estonia</option>"
                +"<option value='ET'>Ethiopia</option>"
                +"<option value='FK'>Falkland Islands</option>"
                +"<option value='FO'>Faroe Islands</option>"
                +"<option value='FJ'>Fiji</option>"
                +"<option value='FI'>Finland</option>"
                +"<option value='FR'>France</option>"
                +"<option value='PF'>French Polynesia</option>"
                +"<option value='GA'>Gabon</option>"
                +"<option value='GM'>Gambia</option>"
                +"<option value='GE'>Georgia</option>"
                +"<option value='DE'>Germany</option>"
                +"<option value='GH'>Ghana</option>"
                +"<option value='GI'>Gibraltar</option>"
                +"<option value='GR'>Greece</option>"
                +"<option value='GL'>Greenland</option>"
                +"<option value='GD'>Grenada</option>"
                +"<option value='GU'>Guam</option>"
                +"<option value='GT'>Guatemala</option>"
                +"<option value='GG'>Guernsey</option>"
                +"<option value='GN'>Guinea</option>"
                +"<option value='GW'>Guinea-Bissau</option>"
                +"<option value='GY'>Guyana</option>"
                +"<option value='HT'>Haiti</option>"
                +"<option value='HN'>Honduras</option>"
                +"<option value='HK'>Hong Kong</option>"
                +"<option value='HU'>Hungary</option>"
                +"<option value='IS'>Iceland</option>"
                +"<option value='IN'>India</option>"
                +"<option value='ID'>Indonesia</option>"
                +"<option value='IR'>Iran</option>"
                +"<option value='IQ'>Iraq</option>"
                +"<option value='IE'>Ireland</option>"
                +"<option value='IM'>Isle of Man</option>"
                +"<option value='IL'>Israel</option>"
                +"<option value='IT'>Italy</option>"
                +"<option value='CI'>Ivory Coast</option>"
                +"<option value='JM'>Jamaica</option>"
                +"<option value='JP'>Japan</option>"
                +"<option value='JE'>Jersey</option>"
                +"<option value='JO'>Jordan</option>"
                +"<option value='KZ'>Kazakhstan</option>"
                +"<option value='KE'>Kenya</option>"
                +"<option value='KI'>Kiribati</option>"
                +"<option value='XK'>Kosovo</option>"
                +"<option value='KW'>Kuwait</option>"
                +"<option value='KG'>Kyrgyzstan</option>"
                +"<option value='LA'>Laos</option>"
                +"<option value='LV'>Latvia</option>"
                +"<option value='LB'>Lebanon</option>"
                +"<option value='LS'>Lesotho</option>"
                +"<option value='LR'>Liberia</option>"
                +"<option value='LY'>Libya</option>"
                +"<option value='LI'>Liechtenstein</option>"
                +"<option value='LT'>Lithuania</option>"
                +"<option value='LU'>Luxembourg</option>"
                +"<option value='MO'>Macao</option>"
                +"<option value='MK'>Macedonia</option>"
                +"<option value='MG'>Madagascar</option>"
                +"<option value='MW'>Malawi</option>"
                +"<option value='MY'>Malaysia</option>"
                +"<option value='MV'>Maldives</option>"
                +"<option value='ML'>Mali</option>"
                +"<option value='MT'>Malta</option>"
                +"<option value='MH'>Marshall Islands</option>"
                +"<option value='MR'>Mauritania</option>"
                +"<option value='MU'>Mauritius</option>"
                +"<option value='YT'>Mayotte</option>"
                +"<option value='MX'>Mexico</option>"
                +"<option value='FM'>Micronesia</option>"
                +"<option value='MD'>Moldova</option>"
                +"<option value='MC'>Monaco</option>"
                +"<option value='MN'>Mongolia</option>"
                +"<option value='ME'>Montenegro</option>"
                +"<option value='MS'>Montserrat</option>"
                +"<option value='MA'>Morocco</option>"
                +"<option value='MZ'>Mozambique</option>"
                +"<option value='MM'>Myanmar</option>"
                +"<option value='NA'>Namibia</option>"
                +"<option value='NR'>Nauru</option>"
                +"<option value='NP'>Nepal</option>"
                +"<option value='NL'>Netherlands</option>"
                +"<option value='AN'>Netherlands Antilles</option>"
                +"<option value='NC'>New Caledonia</option>"
                +"<option value='NZ'>New Zealand</option>"
                +"<option value='NI'>Nicaragua</option>"
                +"<option value='NE'>Niger</option>"
                +"<option value='NG'>Nigeria</option>"
                +"<option value='NU'>Niue</option>"
                +"<option value='KP'>North Korea</option>"
                +"<option value='MP'>Northern Mariana Islands</option>"
                +"<option value='NO'>Norway</option>"
                +"<option value='OM'>Oman</option>"
                +"<option value='PK'>Pakistan</option>"
                +"<option value='PW'>Palau</option>"
                +"<option value='PS'>Palestine</option>"
                +"<option value='PA'>Panama</option>"
                +"<option value='PG'>Papua New Guinea</option>"
                +"<option value='PY'>Paraguay</option>"
                +"<option value='PE'>Peru</option>"
                +"<option value='PH'>Philippines</option>"
                +"<option value='PN'>Pitcairn</option>"
                +"<option value='PL'>Poland</option>"
                +"<option value='PT'>Portugal</option>"
                +"<option value='PR'>Puerto Rico</option>"
                +"<option value='QA'>Qatar</option>"
                +"<option value='CG'>Republic of the Congo</option>"
                +"<option value='RE'>Reunion</option>"
                +"<option value='RO'>Romania</option>"
                +"<option value='RU'>Russia</option>"
                +"<option value='RW'>Rwanda</option>"
                +"<option value='BL'>Saint Barthelemy</option>"
                +"<option value='SH'>Saint Helena</option>"
                +"<option value='KN'>Saint Kitts and Nevis</option>"
                +"<option value='LC'>Saint Lucia</option>"
                +"<option value='MF'>Saint Martin</option>"
                +"<option value='PM'>Saint Pierre and Miquelon</option>"
                +"<option value='VC'>Saint Vincent and the Grenadines</option>"
                +"<option value='WS'>Samoa</option>"
                +"<option value='SM'>San Marino</option>"
                +"<option value='ST'>Sao Tome and Principe</option>"
                +"<option value='SA'>Saudi Arabia</option>"
                +"<option value='SN'>Senegal</option>"
                +"<option value='RS'>Serbia</option>"
                +"<option value='SC'>Seychelles</option>"
                +"<option value='SL'>Sierra Leone</option>"
                +"<option value='SG'>Singapore</option>"
                +"<option value='SX'>Sint Maarten</option>"
                +"<option value='SK'>Slovakia</option>"
                +"<option value='SI'>Slovenia</option>"
                +"<option value='SB'>Solomon Islands</option>"
                +"<option value='SO'>Somalia</option>"
                +"<option value='ZA'>South Africa</option>"
                +"<option value='KR'>South Korea</option>"
                +"<option value='SS'>South Sudan</option>"
                +"<option value='ES'>Spain</option>"
                +"<option value='LK'>Sri Lanka</option>"
                +"<option value='SD'>Sudan</option>"
                +"<option value='SR'>Suriname</option>"
                +"<option value='SJ'>Svalbard and Jan Mayen</option>"
                +"<option value='SZ'>Swaziland</option>"
                +"<option value='SE'>Sweden</option>"
                +"<option value='CH'>Switzerland</option>"
                +"<option value='SY'>Syria</option>"
                +"<option value='TW'>Taiwan</option>"
                +"<option value='TJ'>Tajikistan</option>"
                +"<option value='TZ'>Tanzania</option>"
                +"<option value='TH'>Thailand</option>"
                +"<option value='TG'>Togo</option>"
                +"<option value='TK'>Tokelau</option>"
                +"<option value='TO'>Tonga</option>"
                +"<option value='TT'>Trinidad and Tobago</option>"
                +"<option value='TN'>Tunisia</option>"
                +"<option value='TR'>Turkey</option>"
                +"<option value='TM'>Turkmenistan</option>"
                +"<option value='TC'>Turks and Caicos Islands</option>"
                +"<option value='TV'>Tuvalu</option>"
                +"<option value='VI'>U.S. Virgin Islands</option>"
                +"<option value='UG'>Uganda</option>"
                +"<option value='UA'>Ukraine</option>"
                +"<option value='AE'>United Arab Emirates</option>"
                +"<option value='GB'>United Kingdom</option>"
                +"<option value='US'>United States</option>"
                +"<option value='UY'>Uruguay</option>"
                +"<option value='UZ'>Uzbekistan</option>"
                +"<option value='VU'>Vanuatu</option>"
                +"<option value='VA'>Vatican</option>"
                +"<option value='VE'>Venezuela</option>"
                +"<option value='VN'>Vietnam</option>"
                +"<option value='WF'>Wallis and Futuna</option>"
                +"<option value='EH'>Western Sahara</option>"
                +"<option value='YE'>Yemen</option>"
                +"<option value='ZM'>Zambia</option>"
                +"<option value='ZW'>Zimbabwe</option>"
              +"</select>"
  };
}])

.directive('goNative', ['$ionicGesture', '$ionicPlatform', function($ionicGesture, $ionicPlatform) {
  return {
    restrict: 'A',
 
    link: function(scope, element, attrs) {
 
      $ionicGesture.on('tap', function(e) {
 
        var direction = attrs.direction;
        var transitiontype = attrs.transitiontype;
 
        $ionicPlatform.ready(function() {
 
          switch (transitiontype) {
            case "slide":
              window.plugins.nativepagetransitions.slide({
                  "direction": direction
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
              break;
            case "flip":
              window.plugins.nativepagetransitions.flip({
                  "direction": direction
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
              break;
               
            case "fade":
              window.plugins.nativepagetransitions.fade({
                   
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
              break;
 
            case "drawer":
              window.plugins.nativepagetransitions.drawer({
                  "origin"         : direction,
                  "action"         : "open"
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
              break;
               
            case "curl":
              window.plugins.nativepagetransitions.curl({
                  "direction": direction
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
              break;              
               
            default:
              window.plugins.nativepagetransitions.slide({
                  "direction": direction
                },
                function(msg) {
                  console.log("success: " + msg)
                },
                function(msg) {
                  alert("error: " + msg)
                }
              );
          }
 
 
        });
      }, element);
    }
  };
}])
.directive('lazyImgTopic', function () {
  // Returning the Directive Definition Object
  return {
    restrict: "E",
    scope: false,
    link: function (scope, element, attrs) {
      var options = {
        bind: 'event',
        effect: "fadeIn",
        effectTime: 500,
        delay: 0,
        appendScroll: $('#lztopic'),
        beforeLoad: function (loadedElement) {
          // Lazy will call this function, before the image gets loaded
        },
        onLoad: function (loadedElement) {
          // while loading the image, especially on big images, this function will be called
        },
        afterLoad: function (loadedElement) {
          // this will be called after the image is finally loaded
          registerImage(loadedElement);
        },
        onError: function (loadedElement) {
          // is fired when http request != 200
          lazyError(loadedElement);
          loadedElement.attr("src", "img/no-photo-topic.jpg");
        }
      };

      if(scope.lazyOptions != undefined) {
        angular.extend(scope.lazyOptions, options);
      }

      // attribute conversion from the pseudo markup into real markup accepted by jquery plugin.
      var attributes = '';
      for(var prop in attrs) {
          if(prop.charAt(0) != '$') {
            if(prop == 'title') attributes += ' data-src="' + attrs[prop] + '" ';  // special case src attribute into data-src.
            else attributes += ' ' + prop + '="' + attrs[prop] + '" '; // one-to-one mapping for all other attributes.
          }
      }

      var imageTag = $('<img ' + attributes + ' />');
      element.replaceWith(imageTag);

      var registerImage = function (loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgLazyLoaded', loadedElement);
      };

      var lazyError = function(loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgNotLazyLoaded', [loadedElement, loadedElement.attr("data-src")]);
      };

      imageTag.lazy(options);
    }
  };
})
.directive('lazyImgLoading', function () {
  // Returning the Directive Definition Object
  return {
    restrict: "E",
    scope: false,
    link: function (scope, element, attrs) {
      var options = {
        bind: 'event',
        effect: "fadeIn",
        effectTime: 500,
        delay: 0,
        appendScroll: $('#conloading'),
        defaultImage: "img/loadingto.gif",
        beforeLoad: function (loadedElement) {
          // Lazy will call this function, before the image gets loaded
        },
        onLoad: function (loadedElement) {
          // while loading the image, especially on big images, this function will be called
        },
        afterLoad: function (loadedElement) {
          // this will be called after the image is finally loaded
          registerImage(loadedElement);
          loadedElement[0].classList.remove("hasloadingimg");
        },
        onError: function (loadedElement) {
          // is fired when http request != 200
          lazyError(loadedElement);
          loadedElement[0].classList.remove("hasloadingimg");
          loadedElement.attr("src", "img/no-photo-topic.jpg");
        }
      };

      if(scope.lazyOptions != undefined) {
        angular.extend(scope.lazyOptions, options);
      }

      // attribute conversion from the pseudo markup into real markup accepted by jquery plugin.
      var attributes = '';
      for(var prop in attrs) {
          if(prop.charAt(0) != '$') {
            if(prop == 'title') attributes += ' data-src="' + attrs[prop] + '" ';  // special case src attribute into data-src.
            else attributes += ' ' + prop + '="' + attrs[prop] + '" '; // one-to-one mapping for all other attributes.
          }
      }

      var imageTag = $('<img ' + attributes + ' />');
      element.replaceWith(imageTag);

      var registerImage = function (loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgLazyLoaded', loadedElement);
      };

      var lazyError = function(loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgNotLazyLoaded', [loadedElement, loadedElement.attr("data-src")]);
      };

      imageTag.lazy(options);
    }
  };
})
.directive('lazyImgQuip', function () {
  // Returning the Directive Definition Object
  return {
    restrict: "E",
    scope: false,
    link: function (scope, element, attrs) {
      var options = {
        bind: 'event',
        effect: "fadeIn",
        effectTime: 500,
        appendScroll: $('#lzquip'),
        beforeLoad: function (loadedElement) {
          // Lazy will call this function, before the image gets loaded
        },
        onLoad: function (loadedElement) {
          // while loading the image, especially on big images, this function will be called
        },
        afterLoad: function (loadedElement) {
          // this will be called after the image is finally loaded
          registerImage(loadedElement);
        },
        onError: function (loadedElement) {
          // is fired when http request != 200
          lazyError(loadedElement);
        }
      };

      if(scope.lazyOptions != undefined) {
        angular.extend(scope.lazyOptions, options);
      }

      // attribute conversion from the pseudo markup into real markup accepted by jquery plugin.
      var attributes = '';
      for(var prop in attrs) {
          if(prop.charAt(0) != '$') {
            if(prop == 'title') attributes += ' data-src="' + attrs[prop] + '" ';  // special case src attribute into data-src.
            else attributes += ' ' + prop + '="' + attrs[prop] + '" '; // one-to-one mapping for all other attributes.
          }
      }

      var imageTag = $('<img ' + attributes + ' />');
      element.replaceWith(imageTag);

      var registerImage = function (loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgLazyLoaded', loadedElement);
      };

      var lazyError = function(loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgNotLazyLoaded', [loadedElement, loadedElement.attr("data-src")]);
      };

      imageTag.lazy(options);
    }
  };
})
.directive('lazyImg', function () {
  // Returning the Directive Definition Object
  return {
    restrict: "E",
    scope: false,
    link: function (scope, element, attrs) {
      var options = {
        bind: 'event',
        effect: "fadeIn",
        effectTime: 100,
        delay: 0,
        appendScroll: $('#lzcon'),
        beforeLoad: function (loadedElement) {
          // Lazy will call this function, before the image gets loaded
        },
        onLoad: function (loadedElement) {
          // while loading the image, especially on big images, this function will be called
        },
        afterLoad: function (loadedElement) {
          // this will be called after the image is finally loaded
          registerImage(loadedElement);
        },
        onError: function (loadedElement) {
          loadedElement[0].setAttribute("class", "errorimg");
          lazyError(loadedElement);
          loadedElement.attr("src", "img/no-photo-topic.jpg");
        }
      };

      if(scope.lazyOptions != undefined) {
        angular.extend(scope.lazyOptions, options);
      }

      // attribute conversion from the pseudo markup into real markup accepted by jquery plugin.
      var attributes = '';
      for(var prop in attrs) {
          if(prop.charAt(0) != '$') {
            if(prop == 'title') attributes += ' data-src="' + attrs[prop] + '" ';  // special case src attribute into data-src.
            else attributes += ' ' + prop + '="' + attrs[prop] + '" '; // one-to-one mapping for all other attributes.
          }
      }

      var imageTag = $('<img ' + attributes + ' />');
      element.replaceWith(imageTag);

      var registerImage = function (loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgLazyLoaded', loadedElement);
      };

      var lazyError = function(loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgNotLazyLoaded', [loadedElement, loadedElement.attr("data-src")]);
      };

      imageTag.lazy(options);
    }
  };
})
.directive('lazyImgTh', function () {
  // Returning the Directive Definition Object
  return {
    restrict: "E",
    scope: false,
    link: function (scope, element, attrs) {
      var options = {
        bind: 'event',
        effect: "fadeIn",
        effectTime: 500,
        appendScroll: $('#lzconth'),
        beforeLoad: function (loadedElement) {
          // Lazy will call this function, before the image gets loaded
        },
        onLoad: function (loadedElement) {
          // while loading the image, especially on big images, this function will be called
        },
        afterLoad: function (loadedElement) {
          // this will be called after the image is finally loaded
          registerImage(loadedElement);
        },
        onError: function (loadedElement) {
          loadedElement[0].setAttribute("class", "errorimg");
          lazyError(loadedElement);
        }
      };

      if(scope.lazyOptions != undefined) {
        angular.extend(scope.lazyOptions, options);
      }

      // attribute conversion from the pseudo markup into real markup accepted by jquery plugin.
      var attributes = '';
      for(var prop in attrs) {
          if(prop.charAt(0) != '$') {
            if(prop == 'title') attributes += ' data-src="' + attrs[prop] + '" ';  // special case src attribute into data-src.
            else attributes += ' ' + prop + '="' + attrs[prop] + '" '; // one-to-one mapping for all other attributes.
          }
      }

      var imageTag = $('<img ' + attributes + ' />');
      element.replaceWith(imageTag);

      var registerImage = function (loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgLazyLoaded', loadedElement);
      };

      var lazyError = function(loadedElement) {
        // Firing the event upwards.
        scope.$emit('ImgNotLazyLoaded', [loadedElement, loadedElement.attr("data-src")]);
      };

      imageTag.lazy(options);
    }
  };
})

.directive('myMaxlengthx', ['$compile', '$log', function($compile, $log, $scope) {
    return {
        restrict: 'A',
        require: 'ngModel',
        link: function (scope, elem, attrs, ctrl) {
            attrs.$set("ngTrim", "false");
            var maxlength = parseInt(attrs.myMaxlengthx, 10);
            ctrl.$parsers.push(function (value) {
                document.getElementById('bioTextCount').innerHTML = MaxCaptionCount - value.length;
                if (value.length > maxlength)
                {
                    value = value.substr(0, maxlength);
                    ctrl.$setViewValue(value);
                    ctrl.$render();
                }
                return value;
            });
        }
    };
}])

.directive('headerShrinkMp', function($document) {
  var fadeAmt;

  var shrink = function(header, content, amt, max) {
    amt = Math.min(225, amt);
    var headerstop = $document[0].body.querySelector('#headstopmp');
    var amnth = 225;
    fadeAmt = 1 - amt / 225;
    ionic.requestAnimationFrame(function() {
      header.setAttribute("style", "-webkit-transform: translateZ(0);-webkit-transform:translate3d(0, -" + amt + "px, 0);transform:translate3d(0, -" + amt + "px, 0);-moz-transform:translate3d(0, -" + amt + "px, 0)");
      //header.style[ionic.CSS.TRANSFORM] = 'translate3d(0, -' + amt + 'px, 0)';

      if(amt == 225){
        $('.hideaddressmp').show();
        $('.mptitle').hide();
      }else{
        $('.hideaddressmp').hide();
        $('.mptitle').show();
      }
      for(var i = 0, j = header.children.length; i < j; i++) {
        //header.children[i].style.opacity = fadeAmt;
        var v = amnth - amt;
        headerstop.style.height = v+"px";
      }
    });
  };

  return {
    restrict: 'A',
    link: function($scope, $element, $attr) {
      var starty = $scope.$eval($attr.headerShrink) || 0;
      var shrinkAmt;
      
      var header = $document[0].body.querySelector('.mptitleheader');
      var headerHeight = header.offsetHeight;
      
      $(".containerprofilemp").bind('scroll', function(e) {
        var scrollTop = null;
        if(e.detail){
          scrollTop = e.detail.scrollTop;
        }else if(e.target){
          scrollTop = e.target.scrollTop;
        }
        if(scrollTop > starty){
          // Start shrinking
          shrinkAmt = headerHeight - Math.max(0, (starty + headerHeight) - scrollTop);
          shrink(header, $element[0], shrinkAmt, headerHeight);
        } else {
          shrink(header, $element[0], 0, headerHeight);
        }
      });
    }
  }
})
.directive('headerShrinkVp', function($document) {
  var fadeAmt;

  var shrink = function(header, content, amt, max) {
    amt = Math.min(225, amt);
    var headerstop = $document[0].body.querySelector('#headstopvp');
    var amnth = 225;
    fadeAmt = 1 - amt / 225;
    ionic.requestAnimationFrame(function() {
      header.setAttribute("style", "-webkit-transform: translateZ(0);-webkit-transform:translate3d(0, -" + amt + "px, 0);transform:translate3d(0, -" + amt + "px, 0);-moz-transform:translate3d(0, -" + amt + "px, 0)");
      //header.style[ionic.CSS.TRANSFORM] = 'translate3d(0, -' + amt + 'px, 0)';

      if(amt == 225){
        $('.hideaddressvp').show();
        $('.vptitle').hide();
      }else{
        $('.hideaddressvp').hide();
        $('.vptitle').show();
      }
      for(var i = 0, j = header.children.length; i < j; i++) {
        //header.children[i].style.opacity = fadeAmt;
        var v = amnth - amt;
        headerstop.style.height = v+"px";
      }
    });
  };

  return {
    restrict: 'A',
    link: function($scope, $element, $attr) {
      var starty = $scope.$eval($attr.headerShrink) || 0;
      var shrinkAmt;
      
      var header = $document[0].body.querySelector('.vptitleheader');
      var headerHeight = header.offsetHeight;
      
      $(".containerprofilevp").bind('scroll', function(e) {
        var scrollTop = null;
        if(e.detail){
          scrollTop = e.detail.scrollTop;
        }else if(e.target){
          scrollTop = e.target.scrollTop;
        }
        if(scrollTop > starty){
          // Start shrinking
          shrinkAmt = headerHeight - Math.max(0, (starty + headerHeight) - scrollTop);
          shrink(header, $element[0], shrinkAmt, headerHeight);
        } else {
          shrink(header, $element[0], 0, headerHeight);
        }
      });
    }
  }
})

;
